@@ -32,6 +32,7 @@ import os
 import sys
 import inspect
 import re
+import shutil
 import urllib
 import urlparse
 
@@ -226,3 +227,30 @@ class GenericBaseRecipe(object):
     url = urlparse.urlunparse((scheme, netloc, path, params, query, fragment))
 
     return url
+
+  def setLocationOption(self):
+    if not self.options.get('location'):
+      self.options['location'] = os.path.join(
+          self.buildout['buildout']['parts-directory'], self.name)
+
+  def download(self, destination=None):
+    """ A simple wrapper around h.r.download, downloading to self.location"""
+    self.setLocationOption()
+
+    import hexagonit.recipe.download
+    if not destination:
+      destination = self.location
+    if os.path.exists(destination):
+        # leftovers from a previous failed attempt, removing it.
+        log.warning('Removing already existing directory %s' % destination)
+        shutil.rmtree(destination)
+    os.mkdir(destination)
+
+    try:
+      options = self.options.copy()
+      options['destination'] = destination
+      hexagonit.recipe.download.Recipe(
+          self.buildout, self.name, options).install()
+    except:
+      shutil.rmtree(destination)
+      raise
